==> konos-12.0.1-sources.jar: io/intino/konos/dsl/Theme.java <==
package io.intino.konos.dsl;

import io.intino.konos.dsl.*;

public class Theme  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
	protected Type type;

	public enum Type {
		Normal, Dark;
	}
	protected int contrastThreshold;
	protected double tonalOffset;
	protected java.util.List<io.intino.konos.dsl.Theme.Property> propertyList = new java.util.ArrayList<>();
	protected io.intino.konos.dsl.Theme.Primary primary;
	protected io.intino.konos.dsl.Theme.Secondary secondary;
	protected io.intino.konos.dsl.Theme.Error error;
	protected io.intino.konos.dsl.Theme.Readonly readonly;
	protected io.intino.konos.dsl.Theme.Typography typography;

	public Theme(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public Type type() {
		return type;
	}

	public int contrastThreshold() {
		return contrastThreshold;
	}

	public double tonalOffset() {
		return tonalOffset;
	}

	public Theme type(io.intino.konos.dsl.Theme.Type value) {
		this.type = value;
		return (Theme) this;
	}

	public Theme contrastThreshold(int value) {
		this.contrastThreshold = value;
		return (Theme) this;
	}

	public Theme tonalOffset(double value) {
		this.tonalOffset = value;
		return (Theme) this;
	}

	public java.util.List<io.intino.konos.dsl.Theme.Property> propertyList() {
		return java.util.Collections.unmodifiableList(propertyList);
	}

	public io.intino.konos.dsl.Theme.Property property(int index) {
		return propertyList.get(index);
	}

	public java.util.List<io.intino.konos.dsl.Theme.Property> propertyList(java.util.function.Predicate<io.intino.konos.dsl.Theme.Property> predicate) {
		return propertyList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.konos.dsl.Theme.Property property(java.util.function.Predicate<io.intino.konos.dsl.Theme.Property> predicate) {
		return propertyList().stream().filter(predicate).findFirst().orElse(null);
	}

	public io.intino.konos.dsl.Theme.Primary primary() {
		return primary;
	}

	public io.intino.konos.dsl.Theme.Secondary secondary() {
		return secondary;
	}

	public io.intino.konos.dsl.Theme.Error error() {
		return error;
	}

	public io.intino.konos.dsl.Theme.Readonly readonly() {
		return readonly;
	}

	public io.intino.konos.dsl.Theme.Typography typography() {
		return typography;
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(propertyList).forEach(c -> components.add(c.core$()));
		if (primary != null) components.add(this.primary.core$());
		if (secondary != null) components.add(this.secondary.core$());
		if (error != null) components.add(this.error.core$());
		if (readonly != null) components.add(this.readonly.core$());
		if (typography != null) components.add(this.typography.core$());
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("type", new java.util.ArrayList(java.util.Collections.singletonList(this.type)));
		map.put("contrastThreshold", new java.util.ArrayList(java.util.Collections.singletonList(this.contrastThreshold)));
		map.put("tonalOffset", new java.util.ArrayList(java.util.Collections.singletonList(this.tonalOffset)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Theme$Property")) this.propertyList.add(node.as(io.intino.konos.dsl.Theme.Property.class));
		if (node.is("Theme$Primary")) this.primary = node.as(io.intino.konos.dsl.Theme.Primary.class);
		if (node.is("Theme$Secondary")) this.secondary = node.as(io.intino.konos.dsl.Theme.Secondary.class);
		if (node.is("Theme$Error")) this.error = node.as(io.intino.konos.dsl.Theme.Error.class);
		if (node.is("Theme$Readonly")) this.readonly = node.as(io.intino.konos.dsl.Theme.Readonly.class);
		if (node.is("Theme$Typography")) this.typography = node.as(io.intino.konos.dsl.Theme.Typography.class);
	}

	@Override
	protected void removeNode$(io.intino.magritte.framework.Node node) {
		super.removeNode$(node);
		if (node.is("Theme$Property")) this.propertyList.remove(node.as(io.intino.konos.dsl.Theme.Property.class));
		if (node.is("Theme$Primary")) this.primary = null;
		if (node.is("Theme$Secondary")) this.secondary = null;
		if (node.is("Theme$Error")) this.error = null;
		if (node.is("Theme$Readonly")) this.readonly = null;
		if (node.is("Theme$Typography")) this.typography = null;
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("type")) this.type = io.intino.magritte.framework.loaders.WordLoader.load(values, Type.class, this).get(0);
		else if (name.equalsIgnoreCase("contrastThreshold")) this.contrastThreshold = io.intino.magritte.framework.loaders.IntegerLoader.load(values, this).get(0);
		else if (name.equalsIgnoreCase("tonalOffset")) this.tonalOffset = io.intino.magritte.framework.loaders.DoubleLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("type")) this.type = (Type) values.get(0);
		else if (name.equalsIgnoreCase("contrastThreshold")) this.contrastThreshold = (java.lang.Integer) values.get(0);
		else if (name.equalsIgnoreCase("tonalOffset")) this.tonalOffset = (java.lang.Double) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.konos.dsl.Theme.Primary primary(java.lang.String color) {
			io.intino.konos.dsl.Theme.Primary newElement = core$().graph().concept(io.intino.konos.dsl.Theme.Primary.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Theme.Primary.class);
			newElement.core$().set(newElement, "color", java.util.Collections.singletonList(color));
			return newElement;
		}

		public io.intino.konos.dsl.Theme.Secondary secondary(java.lang.String color) {
			io.intino.konos.dsl.Theme.Secondary newElement = core$().graph().concept(io.intino.konos.dsl.Theme.Secondary.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Theme.Secondary.class);
			newElement.core$().set(newElement, "color", java.util.Collections.singletonList(color));
			return newElement;
		}

		public io.intino.konos.dsl.Theme.Error error(java.lang.String color) {
			io.intino.konos.dsl.Theme.Error newElement = core$().graph().concept(io.intino.konos.dsl.Theme.Error.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Theme.Error.class);
			newElement.core$().set(newElement, "color", java.util.Collections.singletonList(color));
			return newElement;
		}

		public io.intino.konos.dsl.Theme.Readonly readonly(io.intino.konos.dsl.Format format) {
			io.intino.konos.dsl.Theme.Readonly newElement = core$().graph().concept(io.intino.konos.dsl.Theme.Readonly.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Theme.Readonly.class);
			newElement.core$().set(newElement, "format", java.util.Collections.singletonList(format));
			return newElement;
		}

		public io.intino.konos.dsl.Theme.Typography typography() {
			io.intino.konos.dsl.Theme.Typography newElement = core$().graph().concept(io.intino.konos.dsl.Theme.Typography.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Theme.Typography.class);

			return newElement;
		}

	}

	public static abstract class Property  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected java.lang.String color;

		public Property(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public java.lang.String color() {
			return color;
		}

		public Property color(java.lang.String value) {
			this.color = value;
			return (Property) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("color", new java.util.ArrayList(java.util.Collections.singletonList(this.color)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("color")) this.color = io.intino.magritte.framework.loaders.StringLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("color")) this.color = (java.lang.String) values.get(0);
		}

		public Create create() {
			return new Create(null);
		}

		public Create create(java.lang.String name) {
			return new Create(name);
		}

		public class Create  {
			protected final java.lang.String name;

			public Create(java.lang.String name) {
				this.name = name;
			}



		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}

	public static class Primary extends io.intino.konos.dsl.Theme.Property implements io.intino.magritte.framework.tags.Terminal {

		public Primary(io.intino.magritte.framework.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}

	public static class Secondary extends io.intino.konos.dsl.Theme.Property implements io.intino.magritte.framework.tags.Terminal {

		public Secondary(io.intino.magritte.framework.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}

	public static class Error extends io.intino.konos.dsl.Theme.Property implements io.intino.magritte.framework.tags.Terminal {

		public Error(io.intino.magritte.framework.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}

	public static class Readonly  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected io.intino.konos.dsl.Format format;

		public Readonly(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public io.intino.konos.dsl.Format format() {
			return format;
		}

		public Readonly format(io.intino.konos.dsl.Format value) {
			this.format = value;
			return (Readonly) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("format", this.format != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.format)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("format")) this.format = io.intino.magritte.framework.loaders.NodeLoader.load(values, io.intino.konos.dsl.Format.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("format")) this.format = values.get(0)!= null ? core$().graph().load(((io.intino.magritte.framework.Layer) values.get(0)).core$().id()).as(io.intino.konos.dsl.Format.class) : null;
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}

	public static class Typography  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected int fontSize;
		protected java.util.List<java.lang.String> fontFamily = new java.util.ArrayList<>();

		public Typography(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public int fontSize() {
			return fontSize;
		}

		public java.util.List<java.lang.String> fontFamily() {
			return fontFamily;
		}

		public java.lang.String fontFamily(int index) {
			return fontFamily.get(index);
		}

		public java.util.List<java.lang.String> fontFamily(java.util.function.Predicate<java.lang.String> predicate) {
			return fontFamily().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		public Typography fontSize(int value) {
			this.fontSize = value;
			return (Typography) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("fontSize", new java.util.ArrayList(java.util.Collections.singletonList(this.fontSize)));
			map.put("fontFamily", this.fontFamily);
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("fontSize")) this.fontSize = io.intino.magritte.framework.loaders.IntegerLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("fontFamily")) this.fontFamily = io.intino.magritte.framework.loaders.StringLoader.load(values, this);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("fontSize")) this.fontSize = (java.lang.Integer) values.get(0);
			else if (name.equalsIgnoreCase("fontFamily")) this.fontFamily = new java.util.ArrayList<>((java.util.List<java.lang.String>) values);
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}


	public io.intino.konos.dsl.KonosGraph graph() {
		return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
	}
}

==> konos-13.6.1-sources.jar: io/intino/konos/dsl/Theme.java <==
package io.intino.konos.dsl;

import io.intino.konos.dsl.*;

public class Theme  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
	protected Type type;

	public enum Type {
		Light, Dark, Auto;
	}
	protected int contrastThreshold;
	protected double tonalOffset;
	protected java.util.List<io.intino.konos.dsl.Theme.Property> propertyList = new java.util.ArrayList<>();
	protected io.intino.konos.dsl.Theme.Primary primary;
	protected io.intino.konos.dsl.Theme.Secondary secondary;
	protected io.intino.konos.dsl.Theme.Error error;
	protected io.intino.konos.dsl.Theme.Readonly readonly;
	protected io.intino.konos.dsl.Theme.Typography typography;

	public Theme(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public Type type() {
		return type;
	}

	public int contrastThreshold() {
		return contrastThreshold;
	}

	public double tonalOffset() {
		return tonalOffset;
	}

	public Theme type(io.intino.konos.dsl.Theme.Type value) {
		this.type = value;
		return (Theme) this;
	}

	public Theme contrastThreshold(int value) {
		this.contrastThreshold = value;
		return (Theme) this;
	}

	public Theme tonalOffset(double value) {
		this.tonalOffset = value;
		return (Theme) this;
	}

	public java.util.List<io.intino.konos.dsl.Theme.Property> propertyList() {
		return java.util.Collections.unmodifiableList(propertyList);
	}

	public io.intino.konos.dsl.Theme.Property property(int index) {
		return propertyList.get(index);
	}

	public java.util.List<io.intino.konos.dsl.Theme.Property> propertyList(java.util.function.Predicate<io.intino.konos.dsl.Theme.Property> predicate) {
		return propertyList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.konos.dsl.Theme.Property property(java.util.function.Predicate<io.intino.konos.dsl.Theme.Property> predicate) {
		return propertyList().stream().filter(predicate).findFirst().orElse(null);
	}

	public io.intino.konos.dsl.Theme.Primary primary() {
		return primary;
	}

	public io.intino.konos.dsl.Theme.Secondary secondary() {
		return secondary;
	}

	public io.intino.konos.dsl.Theme.Error error() {
		return error;
	}

	public io.intino.konos.dsl.Theme.Readonly readonly() {
		return readonly;
	}

	public io.intino.konos.dsl.Theme.Typography typography() {
		return typography;
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(propertyList).forEach(c -> components.add(c.core$()));
		if (primary != null) components.add(this.primary.core$());
		if (secondary != null) components.add(this.secondary.core$());
		if (error != null) components.add(this.error.core$());
		if (readonly != null) components.add(this.readonly.core$());
		if (typography != null) components.add(this.typography.core$());
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("type", new java.util.ArrayList(java.util.Collections.singletonList(this.type)));
		map.put("contrastThreshold", new java.util.ArrayList(java.util.Collections.singletonList(this.contrastThreshold)));
		map.put("tonalOffset", new java.util.ArrayList(java.util.Collections.singletonList(this.tonalOffset)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Theme$Property")) this.propertyList.add(node.as(io.intino.konos.dsl.Theme.Property.class));
		if (node.is("Theme$Primary")) this.primary = node.as(io.intino.konos.dsl.Theme.Primary.class);
		if (node.is("Theme$Secondary")) this.secondary = node.as(io.intino.konos.dsl.Theme.Secondary.class);
		if (node.is("Theme$Error")) this.error = node.as(io.intino.konos.dsl.Theme.Error.class);
		if (node.is("Theme$Readonly")) this.readonly = node.as(io.intino.konos.dsl.Theme.Readonly.class);
		if (node.is("Theme$Typography")) this.typography = node.as(io.intino.konos.dsl.Theme.Typography.class);
	}

	@Override
	protected void removeNode$(io.intino.magritte.framework.Node node) {
		super.removeNode$(node);
		if (node.is("Theme$Property")) this.propertyList.remove(node.as(io.intino.konos.dsl.Theme.Property.class));
		if (node.is("Theme$Primary")) this.primary = null;
		if (node.is("Theme$Secondary")) this.secondary = null;
		if (node.is("Theme$Error")) this.error = null;
		if (node.is("Theme$Readonly")) this.readonly = null;
		if (node.is("Theme$Typography")) this.typography = null;
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("type")) this.type = io.intino.magritte.framework.loaders.WordLoader.load(values, Type.class, this).get(0);
		else if (name.equalsIgnoreCase("contrastThreshold")) this.contrastThreshold = io.intino.magritte.framework.loaders.IntegerLoader.load(values, this).get(0);
		else if (name.equalsIgnoreCase("tonalOffset")) this.tonalOffset = io.intino.magritte.framework.loaders.DoubleLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("type")) this.type = (Type) values.get(0);
		else if (name.equalsIgnoreCase("contrastThreshold")) this.contrastThreshold = (java.lang.Integer) values.get(0);
		else if (name.equalsIgnoreCase("tonalOffset")) this.tonalOffset = (java.lang.Double) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.konos.dsl.Theme.Primary primary(java.lang.String color) {
			io.intino.konos.dsl.Theme.Primary newElement = core$().graph().concept(io.intino.konos.dsl.Theme.Primary.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Theme.Primary.class);
			newElement.core$().set(newElement, "color", java.util.Collections.singletonList(color));
			return newElement;
		}

		public io.intino.konos.dsl.Theme.Secondary secondary(java.lang.String color) {
			io.intino.konos.dsl.Theme.Secondary newElement = core$().graph().concept(io.intino.konos.dsl.Theme.Secondary.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Theme.Secondary.class);
			newElement.core$().set(newElement, "color", java.util.Collections.singletonList(color));
			return newElement;
		}

		public io.intino.konos.dsl.Theme.Error error(java.lang.String color) {
			io.intino.konos.dsl.Theme.Error newElement = core$().graph().concept(io.intino.konos.dsl.Theme.Error.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Theme.Error.class);
			newElement.core$().set(newElement, "color", java.util.Collections.singletonList(color));
			return newElement;
		}

		public io.intino.konos.dsl.Theme.Readonly readonly(io.intino.konos.dsl.Format format) {
			io.intino.konos.dsl.Theme.Readonly newElement = core$().graph().concept(io.intino.konos.dsl.Theme.Readonly.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Theme.Readonly.class);
			newElement.core$().set(newElement, "format", java.util.Collections.singletonList(format));
			return newElement;
		}

		public io.intino.konos.dsl.Theme.Typography typography() {
			io.intino.konos.dsl.Theme.Typography newElement = core$().graph().concept(io.intino.konos.dsl.Theme.Typography.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Theme.Typography.class);

			return newElement;
		}

	}

	public static abstract class Property  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected java.lang.String color;
		protected java.lang.String darkColor;

		public Property(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public java.lang.String color() {
			return color;
		}

		public java.lang.String darkColor() {
			return darkColor;
		}

		public Property color(java.lang.String value) {
			this.color = value;
			return (Property) this;
		}

		public Property darkColor(java.lang.String value) {
			this.darkColor = value;
			return (Property) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("color", new java.util.ArrayList(java.util.Collections.singletonList(this.color)));
			map.put("darkColor", new java.util.ArrayList(java.util.Collections.singletonList(this.darkColor)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("color")) this.color = io.intino.magritte.framework.loaders.StringLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("darkColor")) this.darkColor = io.intino.magritte.framework.loaders.StringLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("color")) this.color = (java.lang.String) values.get(0);
			else if (name.equalsIgnoreCase("darkColor")) this.darkColor = (java.lang.String) values.get(0);
		}

		public Create create() {
			return new Create(null);
		}

		public Create create(java.lang.String name) {
			return new Create(name);
		}

		public class Create  {
			protected final java.lang.String name;

			public Create(java.lang.String name) {
				this.name = name;
			}



		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}

	public static class Primary extends io.intino.konos.dsl.Theme.Property implements io.intino.magritte.framework.tags.Terminal {

		public Primary(io.intino.magritte.framework.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}

	public static class Secondary extends io.intino.konos.dsl.Theme.Property implements io.intino.magritte.framework.tags.Terminal {

		public Secondary(io.intino.magritte.framework.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}

	public static class Error extends io.intino.konos.dsl.Theme.Property implements io.intino.magritte.framework.tags.Terminal {

		public Error(io.intino.magritte.framework.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}

	public static class Readonly  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected io.intino.konos.dsl.Format format;

		public Readonly(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public io.intino.konos.dsl.Format format() {
			return format;
		}

		public Readonly format(io.intino.konos.dsl.Format value) {
			this.format = value;
			return (Readonly) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("format", this.format != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.format)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("format")) this.format = io.intino.magritte.framework.loaders.NodeLoader.load(values, io.intino.konos.dsl.Format.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("format")) this.format = values.get(0)!= null ? core$().graph().load(((io.intino.magritte.framework.Layer) values.get(0)).core$().id()).as(io.intino.konos.dsl.Format.class) : null;
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}

	public static class Typography  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected int fontSize;
		protected java.util.List<java.lang.String> fontFamily = new java.util.ArrayList<>();

		public Typography(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public int fontSize() {
			return fontSize;
		}

		public java.util.List<java.lang.String> fontFamily() {
			return fontFamily;
		}

		public java.lang.String fontFamily(int index) {
			return fontFamily.get(index);
		}

		public java.util.List<java.lang.String> fontFamily(java.util.function.Predicate<java.lang.String> predicate) {
			return fontFamily().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		public Typography fontSize(int value) {
			this.fontSize = value;
			return (Typography) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("fontSize", new java.util.ArrayList(java.util.Collections.singletonList(this.fontSize)));
			map.put("fontFamily", this.fontFamily);
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("fontSize")) this.fontSize = io.intino.magritte.framework.loaders.IntegerLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("fontFamily")) this.fontFamily = io.intino.magritte.framework.loaders.StringLoader.load(values, this);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("fontSize")) this.fontSize = (java.lang.Integer) values.get(0);
			else if (name.equalsIgnoreCase("fontFamily")) this.fontFamily = new java.util.ArrayList<>((java.util.List<java.lang.String>) values);
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}


	public io.intino.konos.dsl.KonosGraph graph() {
		return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
	}
}
